@@ -361,7 +361,6 @@ static bool convertFileEncoding( const TQString& fileNameIn, TQTextCodec* pCodec
       return false;
    TQTextStream inStream( &in );
    inStream.setCodec( pCodecIn );
-   //inStream.setAutoDetectUnicode( false ); //not available in TQt3, will always detect UCS2
 
    TQFile out( fileNameOut );
    if ( ! out.open( IO_WriteOnly ) )
@@ -379,7 +378,7 @@ static TQTextCodec* detectEncoding( const char* buf, long size, long& skipBytes
 {
    if (size>=2)
    {
-      skipBytes = 0; // In TQt3 UTF-16LE can only be used if autodetected.
+      skipBytes = 0;
       if (buf[0]=='\xFF' && buf[1]=='\xFE' )
          return TQTextCodec::codecForName( "ISO-10646-UCS2" );// "UTF-16LE"
 
