@@ -142,7 +142,7 @@ DiffTextWindow::DiffTextWindow(
 {
    d = new DiffTextWindowData(this);
    d->m_pDiffTextWindowFrame = pParent;
-   setFocusPolicy( TQ_ClickFocus );
+   setFocusPolicy( TQWidget::ClickFocus );
    setAcceptDrops( true );
 
    d->m_pOptionDialog = pOptionDialog;
@@ -847,8 +847,7 @@ void DiffTextWindowData::writeLine(
                   if ( m_pOptionDialog->m_bShowWhiteSpaceCharacters && m_pOptionDialog->m_bShowWhiteSpace)
                   {
                      p.fillRect( xOffset + fontWidth*outPos, yOffset+fontAscent,
-                                 fontWidth*spaces-1, fontDescent, c );  // QT3
-                                 //fontWidth*spaces-1, fontDescent, c );  // QT4
+                                 fontWidth*spaces-1, fontDescent, c );
                   }
                }
                else
@@ -952,13 +951,13 @@ void DiffTextWindow::paintEvent( TQPaintEvent* e )
    int endLine = min2( d->m_firstLine + getNofVisibleLines()+2, getNofLines() );
 
    //if ( invalidRect.size()==size() )
-   {  // double buffering, obsolete with TQt4
-      TQPainter painter(this); // Remove for TQt4
-      TQPixmap pixmap( invalidRect.size() );// Remove for TQt4
+   {
+      TQPainter painter(this);
+      TQPixmap pixmap( invalidRect.size() );
 
-      MyPainter p( TQT_TQPAINTDEVICE(&pixmap), d->m_pOptionDialog->m_bRightToLeftLanguage, width(), fontMetrics().width('W') ); // For TQt4 change pixmap to this
+      MyPainter p( TQT_TQPAINTDEVICE(&pixmap), d->m_pOptionDialog->m_bRightToLeftLanguage, width(), fontMetrics().width('W') );
 
-      p.translate( -invalidRect.x(), -invalidRect.y() );// Remove for TQt4
+      p.translate( -invalidRect.x(), -invalidRect.y() );
 
       p.setFont( font() );
       p.TQPainter::fillRect( invalidRect, d->m_pOptionDialog->m_bgColor );
@@ -967,7 +966,7 @@ void DiffTextWindow::paintEvent( TQPaintEvent* e )
       // p.drawLine( m_invalidRect.x(), m_invalidRect.y(), m_invalidRect.right(), m_invalidRect.bottom() ); // For test only
       p.end();
 
-      painter.drawPixmap( invalidRect.x(), invalidRect.y(), pixmap );// Remove for TQt4
+      painter.drawPixmap( invalidRect.x(), invalidRect.y(), pixmap );
    }
 //    else
 //    {  // no double buffering
@@ -1685,7 +1684,7 @@ bool DiffTextWindowFrame::eventFilter( TQObject* o, TQEvent* e )
       d->m_pLabel->setPalette( p );
       d->m_pTopLine->setPalette( p );
    }
-   if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(d->m_pFileSelection) && e->type()==TQEvent::Drop)
+   if (o == d->m_pFileSelection && e->type()==TQEvent::Drop)
    {
       TQDropEvent* d = static_cast<TQDropEvent*>(e);
       
