@@ -116,7 +116,7 @@ public:
 
 class DirectoryMergeWindow : public TQListView
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
    DirectoryMergeWindow( TQWidget* pParent, OptionDialog* pOptions, TDEIconLoader* pIconLoader );
@@ -332,7 +332,7 @@ protected slots:
 
 class DirectoryMergeInfo : public TQFrame
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
    DirectoryMergeInfo( TQWidget* pParent );
