@@ -336,7 +336,7 @@ TDEMainWindow::TDEMainWindow( TQWidget* parent, const char* name )
 
    m_pToolBar = new TDEToolBar(this);
       
-   memberList = new TQList<TDEMainWindow>;
+   memberList = new TQPtrList<TDEMainWindow>;
    memberList->append(this);
 }
 
