@@ -837,7 +837,7 @@ void KDiff3App::resizeEvent(TQResizeEvent* e)
 
 bool KDiff3App::eventFilter( TQObject* o, TQEvent* e )
 {
-   if( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pMergeResultWindow) )
+   if( o == m_pMergeResultWindow )
    {
       if ( e->type() == TQEvent::KeyPress )
       {  // key press
@@ -929,9 +929,9 @@ bool KDiff3App::eventFilter( TQObject* o, TQEvent* e )
          {
             raise();
             TQString filename = stringList.first();
-            if      ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow1) ) m_sd1.setFilename( filename );
-            else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow2) ) m_sd2.setFilename( filename );
-            else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow3) ) m_sd3.setFilename( filename );
+            if      ( o == m_pDiffTextWindow1 ) m_sd1.setFilename( filename );
+            else if ( o == m_pDiffTextWindow2 ) m_sd2.setFilename( filename );
+            else if ( o == m_pDiffTextWindow3 ) m_sd3.setFilename( filename );
             init();
          }
 #else
@@ -941,9 +941,9 @@ bool KDiff3App::eventFilter( TQObject* o, TQEvent* e )
          {
             raise();
             FileAccess fa( urlList.first().url() );
-            if      ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow1) ) m_sd1.setFileAccess( fa );
-            else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow2) ) m_sd2.setFileAccess( fa );
-            else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow3) ) m_sd3.setFileAccess( fa );
+            if      ( o == m_pDiffTextWindow1 ) m_sd1.setFileAccess( fa );
+            else if ( o == m_pDiffTextWindow2 ) m_sd2.setFileAccess( fa );
+            else if ( o == m_pDiffTextWindow3 ) m_sd3.setFileAccess( fa );
             init();
          }
 #endif
@@ -955,9 +955,9 @@ bool KDiff3App::eventFilter( TQObject* o, TQEvent* e )
          if ( bDecodeSuccess && canContinue() )
          {
             raise();
-            if      ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow1) ) m_sd1.setData(text);
-            else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow2) ) m_sd2.setData(text);
-            else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pDiffTextWindow3) ) m_sd3.setData(text);
+            if      ( o == m_pDiffTextWindow1 ) m_sd1.setData(text);
+            else if ( o == m_pDiffTextWindow2 ) m_sd2.setData(text);
+            else if ( o == m_pDiffTextWindow3 ) m_sd3.setData(text);
             init();
          }
       }
@@ -1447,11 +1447,11 @@ void KDiff3App::slotSelectionStart()
    //editCopy->setEnabled( false );
    //editCut->setEnabled( false );
 
-   const TQObject* s = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
-   if (m_pDiffTextWindow1 && TQT_BASE_OBJECT_CONST(s)!=TQT_BASE_OBJECT(m_pDiffTextWindow1))   m_pDiffTextWindow1->resetSelection();
-   if (m_pDiffTextWindow2 && TQT_BASE_OBJECT_CONST(s)!=TQT_BASE_OBJECT(m_pDiffTextWindow2))   m_pDiffTextWindow2->resetSelection();
-   if (m_pDiffTextWindow3 && TQT_BASE_OBJECT_CONST(s)!=TQT_BASE_OBJECT(m_pDiffTextWindow3))   m_pDiffTextWindow3->resetSelection();
-   if (m_pMergeResultWindow && TQT_BASE_OBJECT_CONST(s)!=TQT_BASE_OBJECT(m_pMergeResultWindow)) m_pMergeResultWindow->resetSelection();
+   const TQObject* s = sender();
+   if (m_pDiffTextWindow1 && s!=m_pDiffTextWindow1)   m_pDiffTextWindow1->resetSelection();
+   if (m_pDiffTextWindow2 && s!=m_pDiffTextWindow2)   m_pDiffTextWindow2->resetSelection();
+   if (m_pDiffTextWindow3 && s!=m_pDiffTextWindow3)   m_pDiffTextWindow3->resetSelection();
+   if (m_pMergeResultWindow && s!=m_pMergeResultWindow) m_pMergeResultWindow->resetSelection();
 }
 
 void KDiff3App::slotSelectionEnd()
